@@ -12,7 +12,7 @@ Usage::
     client: PersonalizeRuntimeClient = boto3.client("personalize-runtime")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -24,7 +24,7 @@ __all__ = ("PersonalizeRuntimeClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -37,7 +37,7 @@ class Exceptions:
 
 class PersonalizeRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
     """
 
@@ -53,21 +53,21 @@ class PersonalizeRuntimeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate_presigned_url)
         """
 
@@ -75,16 +75,16 @@ class PersonalizeRuntimeClient(BaseClient):
         self,
         *,
         campaignArn: str,
-        inputList: List[str],
+        inputList: Sequence[str],
         userId: str,
-        context: Dict[str, str] = None,
+        context: Mapping[str, str] = None,
         filterArn: str = None,
-        filterValues: Dict[str, str] = None
+        filterValues: Mapping[str, str] = None
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
         Re-ranks a list of recommended items for the given user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_personalized_ranking)
         """
 
@@ -95,13 +95,13 @@ class PersonalizeRuntimeClient(BaseClient):
         itemId: str = None,
         userId: str = None,
         numResults: int = None,
-        context: Dict[str, str] = None,
+        context: Mapping[str, str] = None,
         filterArn: str = None,
-        filterValues: Dict[str, str] = None
+        filterValues: Mapping[str, str] = None
     ) -> GetRecommendationsResponseTypeDef:
         """
         Returns a list of recommended items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_recommendations)
         """
