@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -33,16 +33,16 @@ _RequiredGetPersonalizedRankingRequestRequestTypeDef = TypedDict(
     "_RequiredGetPersonalizedRankingRequestRequestTypeDef",
     {
         "campaignArn": str,
-        "inputList": List[str],
+        "inputList": Sequence[str],
         "userId": str,
     },
 )
 _OptionalGetPersonalizedRankingRequestRequestTypeDef = TypedDict(
     "_OptionalGetPersonalizedRankingRequestRequestTypeDef",
     {
-        "context": Dict[str, str],
+        "context": Mapping[str, str],
         "filterArn": str,
-        "filterValues": Dict[str, str],
+        "filterValues": Mapping[str, str],
     },
     total=False,
 )
@@ -76,9 +76,9 @@ _OptionalGetRecommendationsRequestRequestTypeDef = TypedDict(
         "itemId": str,
         "userId": str,
         "numResults": int,
-        "context": Dict[str, str],
+        "context": Mapping[str, str],
         "filterArn": str,
-        "filterValues": Dict[str, str],
+        "filterValues": Mapping[str, str],
     },
     total=False,
 )
